package ch.psi.daq.test.queryrest;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Import;
import org.springframework.context.annotation.PropertySource;
import org.springframework.context.annotation.PropertySources;
import org.springframework.web.servlet.config.annotation.EnableWebMvc;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurationSupport;

import ch.psi.daq.cassandra.reader.DataReader;
import ch.psi.daq.query.processor.QueryProcessor;
import ch.psi.daq.query.processor.cassandra.CassandraQueryProcessorLocal;
import ch.psi.daq.test.cassandra.admin.CassandraAdmin;
import ch.psi.daq.test.cassandra.admin.CassandraAdminImpl;
import ch.psi.daq.test.query.config.LocalQueryTestConfig;
import ch.psi.daq.test.queryrest.query.DummyDataReader;

@Configuration
@PropertySources(value = {
      @PropertySource(value = {"classpath:queryrest-test.properties"})
})
@EnableWebMvc
public class DaqWebMvcConfig extends WebMvcConfigurationSupport {

   // ensure that properties in dispatcher.properties are loaded first and then overwritten by the
   // properties in dispatcher-test.properties
   @Import(value = {LocalQueryTestConfig.class})
   static class InnerConfiguration {
   }
   
   @Bean
   public QueryProcessor queryProcessor() {
      return new CassandraQueryProcessorLocal();
   }
   
   @Bean
   public DataReader dataReader() {
      return new DummyDataReader();
   }
   
   @Bean
   public CassandraAdmin cassandraAdmin() {
      return new CassandraAdminImpl();
   }
}